#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FAST_TOINT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FAST_TOINT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/fast_toint.hpp>

#endif
